@@ -8,7 +8,7 @@ use Module::Pluggable::Object;
 use MRO::Compat;
 use Moose::Util::TypeConstraints;
 
-our $VERSION = '0.91';
+our $VERSION = '0.93';
 $VERSION = eval $VERSION;
 
 has plugins => ( is => 'rw' );
@@ -35,7 +35,7 @@ sub execute {
     my $self = shift;
     my ( $controller, $c ) = @_;
 
-    if ( $self->_deserialize_handles_http_method($c->request->method) ) {
+    if ( !defined($c->req->data) && $self->_deserialize_handles_http_method($c->request->method) ) {
         my ( $sclass, $sarg, $content_type ) =
           $self->_load_content_plugins( 'Catalyst::Action::Deserialize',
             $controller, $c );
